@@ -9,6 +9,7 @@ OC.L10N.register(
     "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
     "Unread articles" : "Lukemattomat artikkelit",
     "News" : "Uutiset",
+    "Shared with me" : "Jaettu kanssasi",
     "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
     "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
     "Purge interval" : "Hävitysväli",
@@ -32,9 +33,14 @@ OC.L10N.register(
     "Unstar article" : "Poista artikkeli suosikeista",
     "Keep article unread" : "Pidä artikkeli lukemattomana",
     "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
+    "Share" : "Jaa",
+    "Share with users" : "Jaa käyttäjien kanssa",
     "Username" : "Käyttäjätunnus",
+    "No users found" : "Käyttäjiä ei löytynyt",
+    "Share on social media" : "Jaa sosiaalisessa mediassa",
     "by" : "Kirjoittaja:",
     "from" : "Syöte:",
+    "shared by" : "jakanut",
     "Play audio" : "Toista äänet",
     "Download audio" : "Lataa äänet",
     "Download video" : "Lataa video",
